/**
 * This script has functions to display the div
 * based popup boxes when the user clicks.
 * This will hide or un-hide the div tags when
 * the user clicks the suitable icon   
 */

/*
 * set the funcion to call when click event occurs
 * AND any key is pressed (to check for Esc)
 * AND scroll is done (to update the position)
 */
document.onclick = checkClick;
document.onkeypress = checkEscKey;
//document.onscroll = updateDivPosition;
window.onscroll  = updateDivPosition;

/*
 * global variables to set if a div is shown
 * and an obj to hold the div id.
 * Assume: only one div is shown at a time
 */
var divShown = false;
var divId = "";
var isLinkClicked = false;
var bgNode = null;
var closeDivId = "popup_close_div";
var closeIcon = "popup_close_icon";

/**
 * This function is called whenever 
 * there is a click event.
 * 
 * @param event
 */
function checkClick(event) {
	var target = (event ? event.target : window.event.srcElement);
	if (target==bgNode || target.id==closeIcon) {
		checkDisplay();
	}
	isLinkClicked = false;
}

/**
 * This function is called on request to close a div
 * In that case hides the div tag if the
 * tag is getting displayed.
 * 
 * @param event
 */
function checkDisplay () {
	if (!isLinkClicked && divShown) {
		document.getElementById(divId).style.display = 'none';
		document.getElementById(closeDivId).style.display = 'none';
		divShown = 0;
		divId = "";
		bgNode.style.display = "none";
	}
}

/**
 * This function is called on clicking any key.
 * Checks if ESC key is pressed and if so calls the 
 * checkDisplay function
 * 
 * @param event
 */
function checkEscKey (event) {
	var key = (window.event ? window.event.keyCode : event.keyCode);
	if (key == 27) {
		checkDisplay();
	}
}

/**
 * This function is called if any of the 
 * link is pressed to display the divs
 * 
 * @param element - div id to display
 */
function popup (element) {
	// set the global variables
	divId = element;
	divShown = true;
	isLinkClicked = true;
	
	//get the element
	var divObject = document.getElementById(divId);
	
	//display a transparent background here
	if (bgNode == null)
		 bgNode = addBackground();
	bgNode.style.display = "block";
	
	//update the properties
	var pos = getDivSize();
	divObject.style.width = pos.width + "px";
	divObject.style.height = pos.height + "px";
	//TODO add a class in css if required to get rid of these
	divObject.style.backgroundColor = "white";
	divObject.style.position = "absolute";
	divObject.style.padding = "10px";
	updateDivPosition(null);
	//divObject.style.margin = "0px 0px";
	divObject.style.zIndex = 1001;
	divObject.style.overflow = "scroll";
	//display the div
	divObject.style.display = 'block';
	

	//append close icon to this div
	var closeDiv = document.getElementById(closeDivId);
	closeDiv.style.display = "block";
	//pos.width += 60;	//to support margin
	//alert(divObject.style.width);
	closeDiv.style.width = divObject.style.width;

 } 

/**
 * This function fetches the screen size and 
 * the scroll position and calculates the 
 * div position so as to get in centre
 * 
 */
function updateDivPosition (event) {
	if (divId=="")
		return;
	var divObject = document.getElementById(divId);
	var screenWidth = (window.innerWidth || document.body.clientWidth);
	var screenHeight = (window.innerHeight || document.body.clientHeight);
	var pos = getDivSize();
	//consider the current position (scroll)
	var top = (screenHeight - pos.height) / 4 + (window.pageYOffset!=null ? window.pageYOffset : document.body.scrollTop);
	var left = (screenWidth - pos.width) / 4 + (document.body.scrollLeft!=null ? document.body.scrollLeft : window.pageXOffset);
	divObject.style.top = top + "px";
	divObject.style.left = left + "px";

	//also update the position of close icon
	var closeDiv = document.getElementById(closeDivId);
	closeDiv.style.left = divObject.style.left;
	top += pos.height;	//add the margin
	closeDiv.style.top = top + "px";
}

/**
 * This function fetches the screen size and 
 * calculate the div size.
 * 
 * returns (width, height)
 */
function getDivSize() {
	var screenWidth = (window.innerWidth || document.body.clientWidth);
	var screenHeight = (window.innerHeight || document.body.clientHeight);
	var width = screenWidth * 0.60 ;	//60%
	var height = screenHeight * 0.60 ;	//60%
	return {
		height : height,
		width : width
	};
}

/**
 * This function adds a transparent div
 * one layer below the div displayed acting as a 
 * transparent background.
 */
function addBackground() {
	var width = (window.innerWidth > document.body.scrollWidth) ? window.innerWidth : document.body.scrollWidth;
	var height = (window.innerHeight > document.body.scrollHeight) ? window.innerHeight : document.body.scrollHeight;
	var bgNode = document.createElement('div');
	bgNode.style.width = width + "px";
	bgNode.style.height = height + "px";
	bgNode.style.top = "0px";
	bgNode.style.left = "0px";
	bgNode.style.display = "none";
	bgNode.style.position = "absolute";
	bgNode.style.zIndex = 1000;
	bgNode.style.opacity = 60;// For FF
	bgNode.style.filter = 'alpha(opacity=' + 80 + ')'; //For IE
	bgNode.style.backgroundImage = "url('images/bg.png')";
	document.body.appendChild(bgNode);

	// add the close icon div here
	var closeDiv = document.createElement("div");
	//closeDiv.style.display = "none";
	closeDiv.id = closeDivId;
	closeDiv.style.background = "white";
	closeDiv.style.position = "absolute";
	closeDiv.style.zIndex = 1002;
	closeDiv.style.padding = "10px";
	closeDiv.innerHTML = "<p align=right>Close<img border=0 title='close' onmouseover=\"this.style.cursor='pointer'\" src='images/close.jpg' id='"+closeIcon+"'/></p>";
	document.body.appendChild(closeDiv);

	return bgNode;
}