#!/usr/bin/perl	 -w

################################################################################
##	File:	       setup.pl
##	Author:	       Vishwanatha Krishnamurthy - vishwank@in.ibm.com
##	Created:       02/02/2012
##	Last modified: 02/09/2012
################################################################################
use Getopt::Long;
if ( ! GetOptions ( 
   "hmc=s" => \$hmc,
   "user=s" => \$hmcuser,
   "ssh=s" => \$ssh_tar_file) ){
   print "\n Usage: ./setup.pl -hmc <HMC hostname> -user <Hmcuser name> -ssh <ssh tar file path> [-hmc and -user are mandatory]\n";
   print "Please provide the absolute path of the ssh tar file\n";
   print "\nNote: Users can download the ssh.tar file from the URL:\n https://www.ibm.com/developerworks/wikis/download/attachments/192577626/ssh.tar?version=1	\n";
   exit;
}
$u = `who am i |cut -c1-4`;
$x = "root\n";
$d= ($u cmp $x);
if ( $d ==0 )
{  $HOME = "/" ;}else {$HOME = "/home/$u" ;}

if ( -f "/usr/bin/ssh") { 
   if (!defined $hmc || !defined $hmcuser ) {
      print "\n Usage: ./setup.pl -hmc <HMC hostname> -user <Hmcuser name> -ssh <ssh tar file path> [-hmc and -user are mandatory]\n";
      exit -1;
   }

   print "\nPlease enter HMC password:";
   $hmcpass = <STDIN>;
   chomp($hmcpass); 
   ssh_configure();
}
else {
   if (!defined $hmc || !defined $hmcuser || !defined $ssh_tar_file) {
       print "\n Usage: ./setup.pl -hmc <HMC hostname> -user <Hmcuser name> -ssh <ssh tar file path> [-hmc and -user are mandatory]\n";
       print "Please provide the absolute path of the ssh tar file\n";
       print "\nNote: Users can download the ssh.tar file from the URL:\n https://www.ibm.com/developerworks/wikis/download/attachments/192577626/ssh.tar?version=1	\n";
       exit -1;
   }

   # users	should download	the tar	file from the web

   $output = `ls $ssh_tar_file`;

   if ($? != 0) {
      print "\n Incorrect ssh.tar file path. Please provide the absolute path of the ssh tar file, exiting........\n";
      exit -1;
   }
   else {
      print "\nPlease enter HMC password:";
      $hmcpass = <STDIN>;
      chomp($hmcpass);

      print "\nssh setup in progress.......\n";
      print "\nssh tar file path: ".$ssh_tar_file;

      print "\nHMC to connect: ".$hmc."\n";

      print "\n Installing ssh.......................\n";
      ssh_install();
   }
}

#################################################################################
# subroutine: ssh_install
# arguments : none
# purpose   : Installs ssh using installp
#################################################################################
sub  ssh_install {
   $output = `ls ssh_install`;
   if ($? == 0) {
	print "\nssh_install directory exists, overwriting ssh_install ...................\n";
   }
   $output = `tar -xvf  $ssh_tar_file`;
   if($? != 0){
	print "\nUnable	to untar $ssh_tar_file\n";
	exit -1;
   }
   print "\n ssh installation log can be found out	at ssh_install.log\n\n";
   $output = `installp -aXYgd  ./ssh_install   -e  ssh_install.log	all` ;
   if($? != 0) {
	print "\nUnable	to install all the packages under ssh_install\n	Error: $output";
	exit -1;
   }
   print "\n SSH package installation has been successful \n\n\n";
   print "\n*********************************************************************************\n";
   ssh_configure();
}



#################################################################################
# subroutine: ssh_configure
# arguments : none
# purpose   : Creates ssh keys,	configures passwordless	authentication with HMC
#################################################################################

sub ssh_configure {
   if  ( -f "$HOME/.ssh/id_rsa.pub") {  
      $ret_value = system ("./script.exp $hmc $hmcuser $hmcpass $HOME 1"); #$value = $ret_value >> 8;
   }
   else {
      $output = `chmod 755 script.exp`;
      if ($? != 0) {
         print "\nEither script.exp not found or unable to set permissions to script.exp, try to set :manually and run setup.pl again\n";
         print "\nexiting...\n";
         exit -1;
      }
      $output	= `ls  ~/.ssh/id*`;
      if ($?	== 0) {
         print "\nssh keys dont exist, generating ssh keys and copying ssh keys onto HMC...\n";
      }
      $ret_value = system("./script.exp  $hmc  $hmcuser $hmcpass $HOME  0");
   }
}
